/// <reference types="@types/react" />
import * as React from 'react';
import { Rules, Fields } from './types';
export declare const validate: (fields: Fields, rules: Rules<Fields>) => Promise<{}>;
export interface Common<F> {
    errors: {
        [key in keyof F]?: string[];
    };
    fields: F;
}
export interface State<F> extends Common<F> {
    isSubmitted: boolean;
}
export declare type Value = {} | undefined | null;
export interface InjectedProps<F> extends Common<F> {
    onValidate: () => Promise<{}>;
    onChange: (x: Array<keyof F> | keyof F, v: Value | Value[]) => void;
}
export declare function withValidation<P, ValidationFields>(passedFields?: ValidationFields, rules?: Rules<ValidationFields>): (WrappedComponent: React.ComponentType<P & InjectedProps<ValidationFields>>) => {
    new (props: P, context?: any): {
        state: {
            errors: {};
            isSubmitted: boolean;
            fields: ValidationFields & {};
        };
        handleValidate: () => Promise<{}>;
        handleChange: (name: string | string[], value: string | number | React.ReactText[]) => void;
        handleValidationResult: (resolve: (t: ValidationFields) => void, reject: (t: Error) => void) => void;
        render(): JSX.Element;
        setState<K extends "errors" | "fields" | "isSubmitted">(state: State<ValidationFields> | ((prevState: Readonly<State<ValidationFields>>, props: P) => State<ValidationFields> | Pick<State<ValidationFields>, K>) | Pick<State<ValidationFields>, K>, callback?: (() => void) | undefined): void;
        forceUpdate(callBack?: (() => void) | undefined): void;
        props: Readonly<{
            children?: React.ReactNode;
        }> & Readonly<P>;
        context: any;
        refs: {
            [key: string]: React.ReactInstance;
        };
    };
};
